==> mylibrary-debug-3.0.2-1-x86_64.pkg.tar.zst: usr/src/debug/mylibrary/mylibrary-3.0.2/src/ArchiveRemoveEntry.cpp <==
/*
 * Copyright (C) 2024 Yury Bobylev <bobilev_yury@mail.ru>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#include <ArchiveRemoveEntry.h>

ArchiveRemoveEntry::ArchiveRemoveEntry()
{

}

ArchiveRemoveEntry::~ArchiveRemoveEntry()
{
  a_read.reset();
  a_write.reset();
}

ArchiveRemoveEntry::ArchiveRemoveEntry(
    const ArchiveRemoveEntry &other)
{
  if(this != &other)
    {
      a_read = other.a_read;
      a_write = other.a_write;
      fl = other.fl;
    }
}

ArchiveRemoveEntry::ArchiveRemoveEntry(ArchiveRemoveEntry &&other)
{
  if(this != &other)
    {
      a_read = other.a_read;
      a_write = other.a_write;
      fl = other.fl;
    }
}

ArchiveRemoveEntry&
ArchiveRemoveEntry::operator=(const ArchiveRemoveEntry &other)
{
  if(this != &other)
    {
      a_read = other.a_read;
      a_write = other.a_write;
      fl = other.fl;
    }
  return *this;
}

ArchiveRemoveEntry&
ArchiveRemoveEntry::operator=(ArchiveRemoveEntry &&other)
{
  if(this != &other)
    {
      a_read = other.a_read;
      a_write = other.a_write;
      fl = other.fl;
    }
  return *this;
}

==> mylibrary-debug-3.1.1-1-x86_64.pkg.tar.zst: usr/src/debug/mylibrary/mylibrary-3.1.1/src/ArchiveRemoveEntry.cpp <==
/*
 * Copyright (C) 2024-2025 Yury Bobylev <bobilev_yury@mail.ru>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#include <ArchiveRemoveEntry.h>

ArchiveRemoveEntry::ArchiveRemoveEntry()
{
}

ArchiveRemoveEntry::~ArchiveRemoveEntry()
{
  a_read.reset();
  a_write.reset();
}

ArchiveRemoveEntry::ArchiveRemoveEntry(const ArchiveRemoveEntry &other)
{
  if(this != &other)
    {
      a_read = other.a_read;
      a_write = other.a_write;
      fl = other.fl;
    }
}

ArchiveRemoveEntry::ArchiveRemoveEntry(ArchiveRemoveEntry &&other)
{
  if(this != &other)
    {
      a_read = other.a_read;
      a_write = other.a_write;
      fl = other.fl;
    }
}

ArchiveRemoveEntry &
ArchiveRemoveEntry::operator=(const ArchiveRemoveEntry &other)
{
  if(this != &other)
    {
      a_read = other.a_read;
      a_write = other.a_write;
      fl = other.fl;
    }
  return *this;
}

ArchiveRemoveEntry &
ArchiveRemoveEntry::operator=(ArchiveRemoveEntry &&other)
{
  if(this != &other)
    {
      a_read = other.a_read;
      a_write = other.a_write;
      fl = other.fl;
    }
  return *this;
}
